EventHandler

Struct EventHandler 

pub struct EventHandler<E: Event> { /* private fields */ }
Routine, which reads and writes events of a concrete type

Implementations

Source

impl<E: Event> EventHandler<E>

pub fn new() -> Self

Instantiate new empty EventHandler

pub fn send(&mut self, event: E)

Send event to the handler

pub fn read(&self) -> Option<E>

Listen for events

pub fn clear(&mut self)

Clear events. It is called by the engine at every schedule run